use super::*;

use winapi::um::consoleapi::{GetConsoleMode, SetConsoleMode};

/// Obtains info about a console's mode
///
/// See [`GetConsoleMode`](https://docs.microsoft.com/en-us/windows/console/getconsolemode)
#[inline]
pub unsafe fn get_console_mode(handle: HANDLE) -> Result<u32, ErrorCode> {
  let mut mode: u32 = 0;
  if GetConsoleMode(handle, &mut mode) != 0 {
    Ok(mode)
  } else {
    Err(get_last_error())
  }
}

/// Sets a console mode configuration.
///
/// See [`SetConsoleMode`](https://docs.microsoft.com/en-us/windows/console/setconsolemode)
#[inline]
pub unsafe fn set_console_mode(handle: HANDLE, mode: u32) -> Result<(), ErrorCode> {
  if SetConsoleMode(handle, mode) != 0 {
    Ok(())
  } else {
    Err(get_last_error())
  }
}
