use super::*;

use winapi::um::libloaderapi::GetModuleHandleW;

/// See [`GetModuleHandleW`](https://docs.microsoft.com/en-us/windows/win32/api/libloaderapi/nf-libloaderapi-getmodulehandlew)
#[inline]
pub unsafe fn get_module_handle(opt_name: Option<&str>) -> Result<HMODULE, ErrorCode> {
  let module = match opt_name {
    Some(name) => {
      let name_wide = wide_null(name);
      GetModuleHandleW(name_wide.as_ptr())
    }
    None => GetModuleHandleW(null()),
  };
  if module.is_null() {
    Err(get_last_error())
  } else {
    Ok(module)
  }
}
