use super::*;

use winapi::um::processenv::{GetStdHandle, SetStdHandle};

/// Obtains one of the process's standard handles.
///
/// * Note that the handle returned on success can still be the `NULL` handle.
///
/// See
/// [`GetStdHandle`](https://docs.microsoft.com/en-us/windows/console/getstdhandle)
#[inline]
pub fn get_std_handle(std_handle: StdHandle) -> Result<HANDLE, ErrorCode> {
  let handle = unsafe { GetStdHandle(std_handle as u32) };
  if handle != winapi::um::handleapi::INVALID_HANDLE_VALUE {
    Ok(handle)
  } else {
    Err(get_last_error())
  }
}

/// Sets one of the process's standard handles.
///
/// See
/// [`SetStdHandle`](https://docs.microsoft.com/en-us/windows/console/setstdhandle)
#[inline]
pub unsafe fn set_std_handle(std_handle: StdHandle, handle: HANDLE) -> Result<(), ErrorCode> {
  if SetStdHandle(std_handle as u32, handle) != 0 {
    Ok(())
  } else {
    Err(get_last_error())
  }
}
